# BotSniffer

Detects source code generated by AI on projects using Machine Learning and "Feature Extraction."

## Usage

### On the command line

You can use botsniffer in your terminal as command line. You need to train the tool before being able to detect code.

I included some AI generated snippets, but you need to incorporate a bigger dataset in order to make it fully functional.

```
$ pip3 install botsniffer
$ botsniffer ./ --train (will train using the code in the current directory. Any files with "ai" in the name will be taken as AI generated).
$ botsniffer ./ --identify (will list feature extraction scores plus AI as True/False)

## Notice

This tool does not provide legal advice; I'm not a lawyer.

The code is an experimental implementation. Refrain from relying on the accuracy of the output of this tool.

## Contributing

Contributions are very welcome! See [CONTRIBUTING](CONTRIBUTING.md) for more info.

## License

This code is licensed under the [Apache 2.0 License](LICENSE).